## Version 0.1.3
Unreleased
- Add CSV report
- Change default report name to 'report_<project_name>'
- Remove aggregate, last_version_only, and before

## Version 0.1.2
Released 2025-04-22
- Set an explicit Y minimum of 0 in charts.
- Skip non-Git repositories in a directory containing multiple Git repositories.
- Add version command line arg (`-v` and `--version`).
- Improve `cli` help messages and README.

## Version 0.1.1
Released 2025-04-16
- First public release.
